import pygame
import random
import math

(width, height) = (500, 500)
drag = 0.999
elasticity = 0.85

screen = pygame.display.set_mode((width, height))
pygame.display.set_caption("Bouncing Ball Game")

clicked = False

class Ball():
    def __init__(self, (x, y), size):
        self.x = x
        self.y = y
        self.size = size
        self.colour = (0, 173, 173)
        self.thickness = 0
        self.speed = 0
        self.angle = 0

    def display(self):
        pygame.draw.circle(screen, self.colour, (int(self.x), int(self.y)), self.size, self.thickness)

    def move(self):
        self.x = self.x + math.sin(self.angle) * self.speed
        self.y = self.y - math.cos(self.angle) * self.speed
        self.speed = self.speed * drag

    def bounce(self):
        if self.x > width - self.size:
            self.x = 2*(width - self.size) - self.x
            self.angle = - self.angle
            self.speed = self.speed * elasticity

        elif self.x < self.size:
            self.x = 2*self.size - self.x
            self.angle = - self.angle
            self.speed = self.speed * elasticity

        if self.y > height - self.size:
            self.y = 2*(height - self.size) - self.y
            self.angle = math.pi - self.angle
            self.speed = self.speed * elasticity

        elif self.y < self.size:
            self.y = 2*self.size - self.y
            self.angle = math.pi - self.angle
            self.speed = self.speed * elasticity

ball = Ball((250, 250), 20)
ball.speed = 0
ball.angle = random.uniform(0, math.pi*2)

running = True
while running:
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            running = False
        elif event.type == pygame.MOUSEBUTTONDOWN:
            (mouseX, mouseY) = pygame.mouse.get_pos()
            clicked = True
            if clicked:
            	dx = mouseX - ball.x
            	dy = mouseY - ball.y
            	ball.angle = 0.5*math.pi + math.atan2(dy, dx)
            	ball.speed = math.hypot(dx, dy) * 0.1       
        elif event.type == pygame.MOUSEBUTTONUP:
            clicked = False
    screen.fill((173,173,173))
    ball.move()
    ball.bounce()
    ball.display()

    pygame.display.flip()